import { Base64 } from "js-base64";
import api from "./core/api";
import request from "./core/request";
/** 登陆 */
export function login(params: { username: string; password: string }) {
  return request<Resp<API.LoginRespDto>>(api.loginDev + "/auth/oauth2/token", {
    method: "POST",

    header: {
      Authorization: `Basic ${Base64.encode("cgtf:cgtf")}`,
      "Content-Type": "application/x-www-form-urlencoded",
    },
    data: {
      ...params,
      grant_type: "password",
      scope: "server",
    },
  });
}

export function getUserInfo() {
  return request<Resp<API.UserInfoRespDto>>(
    api.loginDev + "/app/app-user/info",
    {
      method: "GET",
    }
  );
}

/** 获取模版配置 */
export function getTemplateConfig(id: string) {
  return request("/hncy/matterInfo/getInfo", {
    method: "POST",
    params: {
      id,
    },
  });
}

/** 获取申请内容 */
export function getApplicationFormDetail(id: string) {
  return request("/hncy/record/getDetails", {
    method: "POST",
    params: { id },
  });
}

/** 获取全部待办 */
export function getBacklog(params: any) {
  return request("/hncy/record/listByWechat", {
    method: "POST",
    params: params,
  });
}

/** 获取全部已办 */
export function getBacklogHistory(params: any) {
  return request("/hncy/record/listByWechat", {
    method: "POST",
    params: { ...params, done: true },
  });
}

export function getExamineHistory(id: string) {
  return request("/hncy/flow/approve-history-list", {
    method: "GET",
    data: {
      businessId: id,
    },
  });
}
export function completeExamine(data) {
  return request("/hncy/flow/complete", {
    method: "POST",

    header: {
      "content-type": "application/x-www-form-urlencoded",
    },
    data,
  });
}
export function submitForm(data) {
  return request("/hncy/record/approveEditReportContent", {
    method: "POST",
    data,
  });
}



/** 获取下个节点的人员 */
export function getNextNodeUser(data: any) {
  return request("/hncy/flow/query-next-approval-users", {
    method:'POST',
    header: {
      "content-type": "application/x-www-form-urlencoded",
    },
    data,
  });
}

/** 获取我的签名 */
export function mySign(userId: string) {
  return request("/hncy/flow/sign-photo?userId=" +userId, {
    method:'POST'
  });
}