import Taro from "@tarojs/taro";
import apiConfig from "./api";

/** 对象转参数 */
export function objectToQuery(obj) {
  return Object.keys(obj)
    .map((k) => encodeURIComponent(k) + "=" + encodeURIComponent(obj[k]))
    .join("&");
}
/** 深度合并 */
function deepMerge<T extends Record<string, any>>(...objects: T[]): T {
  return objects.reduce((prev, obj) => {
    Object.keys(obj).forEach((key) => {
      const prevValue = prev[key];
      const objValue = obj[key];
      if (
        typeof prevValue === "object" &&
        typeof objValue === "object" &&
        prevValue !== null &&
        objValue !== null
      ) {
        //@ts-ignore
        prev[key] = deepMerge(prevValue, objValue);
      } else {
        //@ts-ignore
        prev[key] = objValue;
      }
    });
    return prev;
  }, {} as T);
}

// http规则校验
function urlRegExp(value: string) {
  return /http(s)?:\/\/([\w-]+\.)+[\w-]+(\/[\w-.\/?%&=]*)?/.test(value);
}

/** 请求拦截器 */
const HttpRequestInterceptor = () => {};

/** 响应拦截器 */
const HttpResponseInterceptor = () => {};

const whiteErrList = ["用户名或密码错误",'密码错误次数过多']
/** 简单封装 */
export default function request<T>(
  url: string,
  option: Partial<Taro.request.Option> & { params?: any }
): Promise<T> {
  const params = option.params;

  url = urlRegExp(url) ? url : apiConfig.dev + url;

  if (params) {
    url = url + "?" + objectToQuery(params);
  }

  return new Promise((resolve, reject) => {
    Taro.showLoading({
      title: "数据加载中",
      mask: true,
    });

    Taro.request({
      method: "POST",
      ...option,
      url,
      header: deepMerge<any>(
        {
          Authorization: "Bearer " + Taro.getStorageSync("token"),
          "CLIENT-TOB": "Y",
        },
        option?.header ?? {}
      ),
      success: (res) => {
        resolve(res.data);
      },
      fail: (err) => {
        reject(err);
      },
      complete(err) {
        setTimeout(function () {
          Taro.hideLoading();
        }, 500);
        //token无效
        if ([401, 424].includes(err.statusCode as number)) {
            const msg = err.data?.msg || ''
            const flag = whiteErrList.some((v)=> msg.includes(v))
            if(flag){
              Taro.showModal({
                  title:'提示',
                  content:msg,
                  showCancel:false
              })
              return
            }  
            pastDueWarn()
          }
      },
    });
  });
}

const pastDueWarn = (() => {
    let num = 0
    return () => {
        if (num === 0) {
            num = 1
            Taro.showModal({
                title: '提示',
                content: '用户身份认证过期了，请重新登录',
                confirmText: '确认',
                showCancel: false,
                success: function (res) {
                    num = 0
                    if (res.confirm) {
                        Taro.clearStorageSync();
                        Taro.reLaunch({
                            url: '/pages/index/index',
                        });
                    } else if (res.cancel) {
                        console.log('用户点击取消')
                    }
                }
            })
        }
    }
})()
